# Punto Pagos Python SDK

If you are using this project please send an email to pedro at witoi dot com, and if you are in a good mood send a couple of beers :).

## What's Punto Pagos
* More info at http://www.puntopagos.com/
* This is an independent development.

## Requeriments 
* Tested on python2.6 and python2.7.

## Installation
* `python setup.py install`

## Usage
* Please watch tests.

## TODO
* Retrieve public lists from services at puntopagos.
* Django app (views).

## Authors
* [Pedro Burón](http://pedroburon.info)
* [Alejandro Varas](http://alej0.tk)
